==> discover-5.5.3.tar.xz: discover-5.5.3/libdiscover/backends/ApplicationBackend/tests/SourcesTest.h <==
/***************************************************************************
 *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef SOURCESTEST_H
#define SOURCESTEST_H

#include <QtCore/QObject>

class KXmlGuiWindow;
class AbstractSourcesBackend;
class AbstractResourcesBackend;

class SourcesTest : public QObject
{
    Q_OBJECT
    public:
        explicit SourcesTest(QObject* parent = 0);

    private Q_SLOTS:
        void testSourcesFetch();
        void testResourcesMatchSources();

    private:
        AbstractSourcesBackend* backend() const;

        AbstractResourcesBackend* m_appBackend;
        KXmlGuiWindow* m_window;

};

#endif // REVIEWSTEST_H

==> discover-5.8.4.tar.xz: discover-5.8.4/libdiscover/backends/ApplicationBackend/tests/SourcesTest.h <==
/***************************************************************************
 *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef SOURCESTEST_H
#define SOURCESTEST_H

#include <QtCore/QObject>

class KActionCollection;
class AbstractSourcesBackend;
class AbstractResourcesBackend;

class SourcesTest : public QObject
{
    Q_OBJECT
    public:
        explicit SourcesTest(QObject* parent = nullptr);

    private Q_SLOTS:
        void testSourcesFetch();
        void testResourcesMatchSources();

    private:
        AbstractSourcesBackend* backend() const;

        AbstractResourcesBackend* m_appBackend;
        KActionCollection* m_window;

};

#endif // REVIEWSTEST_H
